/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Törlés"

, "Reply"
: "Válasz"

, "Reply To All"
: "Válasz mindenkinek"

, "Forward"
: "Továbbítás"

, "Print Message"
: "Üzenet nyomtatása"

, "Print Preview"
: "Nyomtatási nézet"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Szabadság"
 ,"Szabadságok"

]
, "Account, Accounts"
: [
  "Fiók"
 ,"Fiókok"

]
, "Account Name"
: "Fiók neve"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Felhasználói email"

, "User Name (From)"
: "Felhasználói név (Feladó)"

, "Organization"
: "Szervezet"

, "Signature position"
: "Aláírás pozíció"

, "Above the quote"
: "Kvóta felett"

, "Below the quote"
: "Kvóta alatt"

, "IMAP"
: "IMAP"

, "Host"
: "Szerver"

, "Port (Default: 143 / SSL: 993)"
: "Port (Alapértelmezett: 143 / SSL: 993)"

, "Secure Connection"
: "Biztonságos kapcsolat"

, "None"
: "Semmi"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Felhasználónév"

, "Password"
: "Jelszó"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (Alapértelmezett: 25)"

, "Authentication"
: "Hitelesítés"

, "Login"
: "Bejelentkezés"

, "Plain"
: "Egyszerű"

, "Username (optional)"
: "Felhasználónév (opcionális)"

, "Password (optional)"
: "Jelszó (opcionális)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Sieve"

, "Port (Default: 2000)"
: "Port (Alapértelmezett: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Egyéb beállítások"

, "Sent Folder Name"
: "Elküldött mappa neve"

, "Trash Folder Name"
: "Szemét mappa neve"

, "Drafts Folder Name"
: "Piszkozatok mappa neve"

, "Templates Folder Name"
: "Sablonok mappa neve"

, "Display Format"
: "Megjelenítés formája"

, "HTML"
: "HTML"

, "Plain Text"
: "Egyszerű szöveg"

, "Depending on content type (experimental)"
: "Tartalom típusától függő (kísérleti)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Írás"

, "Toggle highlighting"
: "Megjelölés váltása"

, "Mark read/unread"
: "Olvasott/olvasatlan jelölés"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Fiók hozzáadása"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Mellékletek"

, "Flags"
: "Zászlók"

, "Subject"
: "Tárgy"

, "From (Email)"
: "Feladó (Email)"

, "From (Name)"
: "Feladó (Név)"

, "Sender"
: "Küldő"

, "To"
: "Címzett"

, "Sent"
: "Elküldött"

, "Received"
: "Beérkezett"

, "Folder, Folders"
: [
  "Mappa"
 ,"Mappák"

]
, "Size"
: "Méret"

, "Answered"
: "Megválaszolt"

, "Forwarded"
: "Továbbított"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Empty Folder"
: "Üres mappa"

, "Add Folder"
: "Mappa hozzáadása"

, "New {0}"
: "Új {0}"

, "Please enter the name of the new {0}:"
: "Kérem adja meg az új {0} nevét:"

, "No {0} added"
: "{0} nincs hozzáadva"

, "You have to supply a {0} name!"
: "Meg kell adnod egy {0} nevet!"

, "Please wait"
: "Kérem várjon"

, "Creating {0}..."
: "{0} elkészítése..."

, "Edit Account"
: "Fiók szerkesztése"

, "Edit Vacation Message"
: "Vakációs üzenet szerkesztése"

, "Edit Filter Rules"
: "Szűrő szabályok szerkesztése"

, "Notifications"
: ""

, "Mark Folder as read"
: "Mappa megjelölése olvasottként"

, "Update Folder List"
: "Mappa lista újratöltése"

, "Message not available."
: ""

, "Cancel"
: "Mégse"

, "Ok"
: "Rendben"

, "Folders of account {0}"
: "{0} fiók mappái"

, "Folders of all accounts"
: "Összes fiók mappái"

, "Compose email"
: "Email írása"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "Feladó"

, "Add"
: "Hozzáadás"

, "Add contact to addressbook"
: "Kapcsolat hozzáadása a Címjegyzékhez"

, "Date"
: "Dátum"

, "Show or hide header information"
: "Fejléc információinak megjelenítése vagy elrejtése"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(új üzenet)"

, "Select recipients for \"{0}\""
: "Válassz ki címzetteket ehhez: \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Címzettek szűrése"

, "All recipients"
: "Minden címzett"

, "\"{0}\" recipients"
: "\"{0}\" címzettek"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Szabadság üzenet ehhez: {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Mozgatás le"

, "Move down"
: "Mozgatás le"

, "Enable"
: "Engedélyezés"

, "Disable"
: "Letiltás"

, "ID"
: "Azonosító"

, "Conditions"
: "Feltételek"

, "Action"
: "Művelet"

, "Keep a copy"
: ""

, "is greater than"
: "nagyobb, mint"

, "is less than"
: "kisebb, mint"

, "Header \"{0}\" contains \"{1}\""
: "Fejléc \"{0}\" \"{1}\" tartalmaz"

, "Header \"{0}\" matches \"{1}\""
: "Fejléc \"{0}\" \"{1}\" tartalmaz"

, "Sieve Filter Rules"
: "Sieve szűrő szabályok"

, "Sieve Filter Rules for {0}"
: "Sieve szűrő feltételek ehhez:{0}"

, "From (Email and Name)"
: "Feladó (Email és Név)"

, "To (Email)"
: "Címzett (Email)"

, "To (Email CC)"
: ""

, "Header contains"
: "Feljéc tartalmaz"

, "Header name"
: "Fejléc neve"

, "Header value"
: "Fejléc érték"

, "Header regex"
: "Fejléc regex"

, "Edit Filter Rule"
: "Szűrő szabály szerkesztése"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Tegye ezt a műveletet:"

, "Move mail to folder"
: "Levél áthelyezése mappába"

, "Redirect mail to address"
: "Levél továbbküldése"

, "Reject mail with this text"
: "Levél visszaküldése ezzel a szöveggel"

, "Discard mail"
: "Levél eldobása"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Levél megtartása"

, "General"
: "Általános"

, "Advanced"
: "Speciális"

, "Only send all X days to the same sender"
: "Csak minden X. napon küldje ugyanannak a címzettnek"

, "Incoming mails will be answered with this text:"
: "A bejövő levelek ezzel a szöveggel lesznek megválaszolva:"

, "Status"
: "Állapot"

, "I am available (vacation message disabled)"
: "Elérhető vagyok (szabadság üzenet letiltva)"

, "I am not available (vacation message enabled)"
: "Nem vagyok elérhető (szabadság üzenet engedélyezve)"

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Üzenet"
 ,"Üzenetek"

]
, "Subject/From"
: "Tárgy/Feladó"

, "Cc"
: "Másolat"

, "Bcc"
: "Titkos másolat"

, "INBOX"
: "BEJÖVŐ ÜZENTEK"

, "Drafts"
: "Piszkozatok"

, "Templates"
: "Sablonok"

, "Junk"
: "Szemét"

, "Trash"
: "Törölt elemek"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "adat lista"
 ,"adat listák"

]
, "Rule, Rules"
: [
  "Szabály"
 ,"Szabályok"

]
, "Flag, Flags"
: [
  "Zászló"
 ,"Zászlók"

]
, "Flag list, Flag lists"
: [
  "Zászló lista"
 ,"Zászló listák"

]
, "Total Messages:"
: "Összes üzenet:"

, "Unread Messages:"
: "Olvasatlan üzenet:"

, "Name on Server:"
: "Név a szerveren:"

, "Last update:"
: "Utolsó frissítés:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} olvasatlan levél"
 ,"{0} olvasatlan levél"

]
, "New Mail"
: "Új levél"

, "Email"
: "Email"

, "Active Vacation Message"
: "Aktív szabadság üzenet"

, "Email account \"{0}\" has an active vacation message."
: "Email fiók \"{0}\" rendelkezik aktív szabadság üzenettel."

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Új levelek"

, "You got {0} new mail(s) in folder {1} ({2})."
: "{0} új üzeneted van a {1} mappában ({2})."

, "IMAP Credentials for {0}"
: "{0} IMAP belépési adatai"

, "Credentials"
: "Belépési adatok"

, "IMAP Error"
: "IMAP hiba"

, "No connection to IMAP server."
: "Nincs kapcsolat az IMAP szerverrel."

, "IMAP Credentials Error"
: "IMAP belépési adatok hibásak"

, "Your email credentials are wrong. Please contact your administrator"
: "Az email belépési adataid rosszak. Lépj kapcsolatba a rendszergazdával."

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Az egyik mappádat egy másik kliens törölte vagy átnevezte. Kérlek frissítsd a mappa listát."

, "SMTP Error"
: "SMTP hiba"

, "No connection to SMTP server."
: "Nincs kapcsolat az SMTP szerverrel."

, "Sieve Error"
: "Sieve hiba"

, "No connection to Sieve server."
: "Nincs kapcsolat a Sieve szerverrel."

, "Save Sieve Script Error"
: "Sieve script hiba mentése"

, "Could not save script on Sieve server."
: "Nem menthető  script a Sieve szerveren."

, "Add as \"To\""
: "Hozzáadás \"To\"-ként"

, "Add as \"Cc\""
: "Hozzáadás \"Cc\"-ként"

, "Add as \"Bcc\""
: "Hozzáadás \"Bcc\"-ként"

, "Remove from recipients"
: "Eltávolítás a címzettek kzül"

, "Loading Mail Addresses"
: "Üzenet címek betöltése"

, "Click here to set To/CC/BCC."
: "Kattints ide a Címzett/Másolat/Titkos Másolat beállításához."

, "To:"
: "Címzett:"

, "Cc:"
: "Másolat:"

, "Bcc:"
: "Titkos másolat:"

, "Remove"
: "Eltávolítás"

, "Send"
: "Küldés"

, "Search Recipients"
: "Címzett keresése"

, "Save As Draft"
: "Mentés piszkozatként"

, "Save As Template"
: "Mentés sablonként"

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Kattints a címzettek kereséséhez és hozzáadásához a Címjegyzékből."

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Továbbítás:"

, "{0} Message"
: "{0} üzenet"

, "Failed"
: "Sikertelen"

, "{0} account setting empty."
: "{0} fiók beállításai üresek."

, "Files are still uploading."
: "Fileok éppen feltöltés alatt állnak."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "{0}, ebből {1} megírt"

, "Original message"
: "Eredeti üzenet"

, "Compose email:"
: "Email írása:"

, "Convert to formated text"
: ""

, "Body"
: "Üzenet"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: "Nincsenek címzettek beállítva."

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Összes beérkezett üzenetek mappa"

, "Default Email Account"
: "Alapértelmezett email fiók"

, "The default email account to use when sending mails."
: "Alapértelmezett email fiók üzenetek küldéséhez."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Email frissítés intervalluma"

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Használja MEGJEGYZÉSKÉNT"

, "Save Note default Value."
: "Alapértelmezett Megjegyzés érték mentése."

, "Confirm Delete"
: "Törlés megerősítése"

, "Show confirmation dialog when deleting mails."
: "Megerősítés ablak mutatása üzenetek törlésekor."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Házon kívül válasz érkezett: %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Seen"
: "Olvasott"

, "Deleted"
: "Törölt"

, "Draft"
: "Piszkozat"

, "Flagged"
: "Zászlóval jelölt"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Email fiókjaim összes beérkezett üzenetek mappája"

, "All unread mail"
: "Összes olvasatlan levél"

, "All unread mail of my email accounts"
: "Email fiókajim összes olvasatlan levele"

, "All highlighted mail"
: "Összes megjelelölt levél"

, "All highlighted mail of my email accounts"
: "Email fiókjaim összes megjelelölt levele"

, "All drafts"
: "Összes piszkozat"

, "All mails with the draft flag"
: "Összes levél piszkozat zászlóval"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "email fiókok kezelése"

, "Edit and delete email accounts"
: "Email fiókok szerkesztése és törlése"

, "Add email accounts"
: "Email fiókok hozzáadása"

, "Create new email accounts"
: "Új email fiókok létrehozása"

, "Vacation"
: "Szabadság"

, "Account"
: "Fiók"

, "Folder"
: "Mappa"

, "Message"
: "Üzenet"

, "record list"
: "adat lista"

, "Rule"
: "Szabály"

, "Flag"
: "Zászló"

, "Flag list"
: "Zászló lista"

, "{0} unread message"
: "{0} olvasatlan levél"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
